pub async fn set_email_delivery_id(
conn: &mut PgConnection,
credit_registration_id: Uuid,
kind: CreditRegistrationNotificationKind,
email_delivery_id: Uuid,
) -> ModelResult<()>Expand description
Records which delivery carries the mail, which is also what takes the row out of the queue.